| Title: | Lies, Damned Lies, and Selective Benchmarks |
|---|---|
| Description: | Correcting two very selectively chosen benchmarks in order to set a record straight. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-07 09:36:00 UTC |
| Source: | https://github.com/eddelbuettel/ldlasb |
Correcting two very selectively chosen benchmarks in order to set a record straight.
Index of help topics:
ldlasb-package Lies, Damned Lies, and Selective Benchmarks other_grow_ other_grow_ other_release_ other_release_ rcpp_grow_ rcpp_grow_ rcpp_release_ rcpp_release_
Dirk Eddelbuettel <[email protected]>
Dirk Eddelbuettel
Grow objects in vector, alternate implementation
n |
A count |
A vector of ānā elements
Protect and release objects in vector, alternate implementation
n |
A count |
Grow objects in vector, Rcpp implementation
n |
A count |
A vector of ānā elements
Protect and release objects in vector, Rcpp implementation
n |
A count |